from setuptools import setup

setup(
	name="mec_jun2023",
	version="1.0.4",
	url="",
	authors=["Alfred Galichon", "Antoine Jacquet"],
	author_email="ag133@nyu.edu",
	licence="GNU",
	python_requires=">= 3",
	py_modules=['pymec_lp'],				# ['pymec_lp', 'pymec_ot', ...]
	description="description of the package"	# can link markdown file here
)